@@ -3,15 +3,15 @@
  * This driver provides the code needed to initialize the CKeditor javascript
  * WYSIWYG editor.
  *
- * Copyright 2009-2012 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2013 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
- * @author    Michael Slusarz <slusarz@horde.org>
- * @category  Horde
- * @copyright http://www.horde.org/licenses/lgpl21 LGPL-2.1
- * @package   Editor
+ * @author   Michael Slusarz <slusarz@horde.org>
+ * @category Horde
+ * @license  http://www.horde.org/licenses/lgpl21 LGPL-2.1
+ * @package  Editor
  */
 class Horde_Editor_Ckeditor extends Horde_Editor
 {
@@ -33,8 +33,8 @@ class Horde_Editor_Ckeditor extends Horde_Editor
         }
 
         $ck_file = empty($params['basic'])
-            ? 'ckeditor.js'
-            : 'ckeditor_basic.js';
+            ? 'ckeditor/ckeditor.js'
+            : 'ckeditor/ckeditor_basic.js';
 
         if (isset($params['config'])) {
             if (is_array($params['config'])) {
